/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.controller;

import java.util.ArrayList;
import java.util.Collection;

import net.sf.mvc.prototype.model.Model;
import net.sf.mvc.prototype.view.OutputView;

/**
 * 
 * {@code AbstractInputController} is a prototype implementation for {@link InputController}.
 * 
 *
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-10-31
 * @see InputController
 * @see net.sf.mvc.prototype.model.Model Model
 *
 * @param <M> type of {@link net.sf.mvc.prototype.Model Model}
 */
public abstract class AbstractInputController<M extends Model<? extends OutputController<? extends OutputView>>> implements
		InputController<M> {

	/**
	 * {@link net.sf.mvc.prototype.model.Model Model}s that are provided with events by this {@code AbstractInputController}.
	 */
	protected final Collection<M> models = new ArrayList<M>();
	
	
	public void addModel(M model) {
		synchronized (models) {
			models.add(model);
		}
	};
	
	public void removeModel(M model) {
		synchronized (models) {
			models.remove(model);
		}
	};

}
