/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.controller;

import java.util.ArrayList;
import java.util.Collection;

import net.sf.mvc.prototype.model.Model;
import net.sf.mvc.prototype.view.OutputView;

/**
 * 
 * {@code AbstractInputOutputController} is a prototype implementation for
 * {@link InputOutputController}.
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-11-01
 * 
 * @param <M>
 *            Type of {@link net.sf.mvc.prototype.model.Model Model}
 * @param <V>
 *            Type of {@link net.sf.mvc.prototype.view.OutputView OutputView}
 */
public abstract class AbstractInputOutputController<M extends Model<? extends OutputController<? extends OutputView>>, V extends OutputView>
		implements InputOutputController<M, V> {

	/**
	 * Models that are controlled by this {@code AbstractInputOutputController}.
	 */
	protected final Collection<M> models = new ArrayList<M>();

	/**
	 * Views that are controlled by this {@code AbstractInputOutputController}.
	 */
	protected final Collection<V> views = new ArrayList<V>();

	/**
	 * 
	 */
	public void addModel(M model) {
		models.add(model);
	}

	/**
	 * 
	 */
	public void removeModel(M model) {
		models.remove(model);
	}

	/**
	 * 
	 */
	public void addViewOut(V view) {
		views.add(view);
	}

	/**
	 * 
	 */
	public void removeViewOut(V view) {
		views.remove(view);
	}

}
