package net.sf.mvc.prototype.controller;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import javax.swing.SwingUtilities;

import net.sf.mvc.prototype.model.Model;
import net.sf.mvc.prototype.view.OutputView;

public abstract class AbstractSwingController<M extends Model<? extends OutputController<? extends OutputView>>, V extends OutputView> extends
		AbstractInputOutputController<M, V> {
	
	/**
	 * Drop all events coming in to other thread in oder to escape from the
	 * AWT-Event thread.
	 */
	private final ExecutorService exe = Executors.newSingleThreadExecutor();
	
	public void shutdownRequest() {
		System.out.println("shutdown request");
		// escape from AWT-event thread
		exe.submit(new Runnable() {
			public void run() {
				AbstractSwingController.this.shutdown();
			}
		});

	}
	
	public void shutdown() {
		// this must be done by AWT-event thread
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				for (V v : views) {
					v.destroyView();
				}
			}
		});

		for (M m : models) {
			m.shutdown();
		}
		exe.shutdown();
	}
	
	/**
	 * 
	 * Perform a task. Use this method to escape incoming tasks from AWT-Event Thread.
	 *
	 * @param task task to run
	 */
	protected void perform(Runnable task){
		exe.submit(task);
	}
}
