/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.controller;

import net.sf.mvc.prototype.model.Model;
import net.sf.mvc.prototype.view.OutputView;

/**
 * 
 * An {@code InputController} handles events coming from
 * {@link net.sf.mvc.prototype.view.InputView InputView} and passes them on to
 * {@link net.sf.mvc.prototype.model.Model Model}.
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-10-31
 * 
 * @param <M>
 *            type of {@link net.sf.mvc.prototype.model.Model Model}
 */
public interface InputController<M extends Model<? extends OutputController<? extends OutputView>>>
		extends Controller {

	/**
	 * 
	 * Add an {@link net.sf.mvc.prototype.model.Model Model} to this
	 * {@code InputController}. All events processed by this
	 * {@code InputController} will be broadcasted to all registered
	 * {@link net.sf.mvc.prototype.model.Model Model}s.
	 * 
	 * @param model
	 *            {@link net.sf.mvc.prototype.model.Model Model} that is added
	 *            to this {@code InputController}
	 */
	void addModel(M model);

	/**
	 * 
	 * Remove an {@link net.sf.mvc.prototype.model.Model Model} from this
	 * {@code InputController}. Processed events will not anymore send to this
	 * {@link Model}.
	 * 
	 * @param model
	 *            {@link net.sf.mvc.prototype.model.Model Model} that is removed
	 *            from this {@code InputController}
	 */
	void removeModel(M model);

	/**
	 * 
	 * Inform all registered {@code Model}s that an application shutdown has
	 * been requested.
	 * 
	 */
	void shutdownRequest();

}
