/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.example.swing;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;

import net.sf.mvc.prototype.SwingUtils;
import net.sf.mvc.prototype.view.AbstractSwingView;

/**
 * 
 *
 * A custom Swing-view.
 *
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-10-31
 *
 */
public class MyView extends AbstractSwingView<MyController>{
	
	@Override
	protected void init() {
		super.init();
		final JButton info = new JButton("Info");
		final JButton warn = new JButton("Warn");
		final JButton error = new JButton("Error");
		
		info.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				for(MyController c : controllerIn){
					c.infoMsg("info button pressed");
				}
			}
		});
		warn.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				for(MyController c : controllerIn){
					c.warnMsg("warn button pressed");
				}
			}
		});
		error.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				for(MyController c : controllerIn){
					c.errorMsg("error button pressed");
				}
			}
		});
		
		frame.getContentPane().add(info);
		frame.getContentPane().add(warn);
		frame.getContentPane().add(error);
	}

	public void infoMsg(String msg) {
		SwingUtils.showInfoMessage("Info", msg);		
	}

	public void warnMsg(String msg) {
		SwingUtils.showInfoMessage("Warn", msg);
	}

	public void errorMsg(String msg) {
		SwingUtils.showErrorMessage("Error", msg);
	}

	@Override
	public void destroyView() {
		System.out.println("Shutting down view");
		super.destroyView();
	}

}
