/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.model;

import java.util.ArrayList;
import java.util.Collection;

import net.sf.mvc.prototype.controller.InputController;
import net.sf.mvc.prototype.controller.OutputController;
import net.sf.mvc.prototype.view.OutputView;

/**
 * 
 * 
 * A prototype implementation for {@link Model}.
 * 
 * <p>
 * <b>Note:</b>{@code AbstractModel} is thread save.
 * </p>
 * 
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-11-01
 * 
 * @param <D>
 *            type of {@link InputController}
 * @param <C>
 *            type of {@link OutputController}
 */
public abstract class AbstractModel<D extends InputController<? extends Model<C>>, C extends OutputController<? extends OutputView>>
		implements Model<C> {

	/**
	 * {@link InputController} that controls this {@code AbstractModel}.
	 */
	protected final D cIn;

	/**
	 * {@link OutputController}'s that are registered to this
	 * {@link AbstractModel}
	 */
	protected final Collection<C> cOut = new ArrayList<C>();

	/**
	 * 
	 * 
	 * Create a new {@link AbstractModel}.
	 * 
	 * @param controller
	 *            {@link InputController} that controls this
	 *            {@code AbstractModel}
	 */
	public AbstractModel(D controller) {
		synchronized (cOut.getClass()) {
			this.cIn = controller;
		}
	}

	/**
	 * 
	 */
	public void addControllerOut(C control) {
		synchronized (cOut) {
			this.cOut.add(control);
		}
	}

	/**
	 * 
	 */
	public void removeControllerOut(C control) {
		synchronized (cOut) {
			this.cOut.remove(control);
		}
	}

}
