/**********************************************************************
Copyright (c) 2010 Alexander Kerner. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
 ***********************************************************************/

package net.sf.mvc.prototype.view;


/**
 * 
 *
 * View of the MVC-Pattern. A View presents info to the user and also takes input from the user.
 *
 * @author <a href="mailto:alex.kerner.24@googlemail.com">Alexander Kerner</a>
 * @version 2010-10-31
 *
 */
public interface View {
	
	/**
	 * 
	 * Enable this {@code View}.
	 * 
	 * <p>
	 * A Swing view for example will call {@link javax.swing.JFrame#show()}.
	 * </p>
	 * 
	 */
	void showView();

	/**
	 * Disable this {@code View} temporally.
	 * 
	 * <p>
	 * A Swing view for example will call {@link javax.swing.JFrame#setVisible(boolean)}.
	 * </p>
	 * 
	 * 
	 */
	void hideView();

	/**
	 * 
	 * Destroy this {@code View}.
	 * 
	 * <p>
	 * A Swing view for example will call {@link javax.swing.JFrame#dispose()}.
	 * </p>
	 * 
	 * 
	 */
	void destroyView();
	
	/**
	 * 
	 * 
	 * Set this {@code View} enabled or disabled.
	 *
	 */
	void setEnabled(boolean enabled);

}
